==> modul8-0.4.0.tgz: package/test/output/output.js <==
(function(){
window.M8 = {data:{}};
var _modul8RequireConfig = {"namespace":"M8","domains":["app","internal","shared","crazy"],"arbiters":{},"logging":false,"main":"app"};
(function(){var a, arbiters, ary, base, domains, exports, glob, makeRequire, name, ns, toAbsPath, _i, _j, _len, _len2, _ref;
var __indexOf = Array.prototype.indexOf || function(item) {
  for (var i = 0, l = this.length; i < l; i++) {
    if (this[i] === item) return i;
  }
  return -1;
};
base = _modul8RequireConfig;
ns = window[base.namespace];
domains = base.domains;
exports = {};
for (_i = 0, _len = domains.length; _i < _len; _i++) {
  name = domains[_i];
  exports[name] = {};
}
exports.data = ns.data;
delete ns.data;
exports.M8 = {};
exports.external = {};
arbiters = [];
_ref = base.arbiters;
for (name in _ref) {
  ary = _ref[name];
  arbiters.push(name);
  a = window[name];
  for (_j = 0, _len2 = ary.length; _j < _len2; _j++) {
    glob = ary[_j];
    delete window[glob];
  }
  exports.M8[name] = a;
}
makeRequire = function(dom, pathName) {
  var DomReg, isRelative;
  DomReg = /^(.*)::/;
  isRelative = function(reqStr) {
    return reqStr.slice(0, 2) === './';
  };
  return function(reqStr) {
    var o, scannable, _k, _len3;
    if (base.logging) {
      console.log("" + dom + ":" + pathName + " <- " + reqStr);
    }
    if (isRelative(reqStr)) {
      scannable = [dom];
      reqStr = toAbsPath(dom, pathName, reqStr.slice(2));
    } else if (DomReg.test(reqStr)) {
      scannable = [reqStr.match(DomReg)[1]];
      reqStr = reqStr.split('::')[1];
    } else if (__indexOf.call(arbiters, reqStr) >= 0) {
      scannable = ['M8'];
    } else {
      scannable = [dom].concat(domains.filter(function(e) {
        return e !== dom;
      }));
    }
    reqStr = reqStr.split('.')[0];
    for (_k = 0, _len3 = scannable.length; _k < _len3; _k++) {
      o = scannable[_k];
      if (exports[o][reqStr]) {
        return exports[o][reqStr];
      }
    }
    if (base.logging) {
      console.error("Unable to resolve require for: " + reqStr);
    }
    return null;
  };
};
toAbsPath = function(domain, pathName, relReqStr) {
  var folders;
  folders = pathName.split('/').slice(0, -1);
  while (relReqStr.slice(0, 3) === '../') {
    folders = folders.slice(0, -1);
    relReqStr = relReqStr.slice(3);
  }
  return folders.concat(relReqStr.split('/')).join('/');
};
ns.define = function(name, domain, fn) {
  var module;
  fn(makeRequire(domain, name), module = {}, exports[domain][name] = {});
  if (module.exports) {
    delete exports[domain][name];
    exports[domain][name] = module.exports;
  }
};
ns.inspect = function(domain) {
  console.log(exports[domain]);
};
ns.domains = function() {
  return domains.concat(['external']);
};
ns.require = makeRequire(base.main, 'CONSOLE');
exports.M8.data = ns.data = function(name, exported) {
  if (exports.data[name]) {
    delete exports.data[name];
  }
  if (exported) {
    exports.data[name] = exported;
  }
};
exports.M8.external = ns.external = function(name, exported) {
  if (exports.external[name]) {
    delete exports.exernal[name];
  }
  if (exported) {
    exports.extenal[name] = exported;
  }
};})();
M8.define('5','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/5','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('control/5','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('5','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('4','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/4','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('5','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('waa/5','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('waa/4','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('4','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('4','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/3','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('3','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('control/4','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('3','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
b = require('./branch1/3.js');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('3','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('control/3','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
b = require('./../3.js');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('2','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('waa/3','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
d = require('shared::branch1/3');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/2','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('2','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('waa/2','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
e = require('internal::2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('2','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('control/2','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('control/1','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('1','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('waa/1','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/1','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('1','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('1','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('control/0','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('0','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('0','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('waa/0','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/0','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('0','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/5','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/4','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch2/5','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch2/4','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/3','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch2/3','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
b = require('./../branch1/3.js');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/2','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch2/2','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
c = require('./../branch1/2.js');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch2/1','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/1','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/0','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch2/0','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('entry','app',function(require, module, exports){exports.app_branch1 = require('branch1/0');
exports.app_branch2 = require('branch2/0');
exports.shared_ = require('shared::0');
exports.shared_branch1 = require('shared::branch1/0');
exports.internal_ = require('internal::0');
exports.internal_control = require('internal::control/0');
exports.crazy_waa = require('crazy::waa/0');
exports.crazy_ = require('crazy::0');});
})();

==> modul8-0.6.1.tgz: package/test/output/output.js <==
(function(){
window.M8 = {data:{}};
var _modul8RequireConfig = {"namespace":"M8","domains":["app","internal","shared","crazy"],"arbiters":{},"logging":false,"main":"app"};
(function(){var DomReg, a, arbiters, ary, base, domains, exports, glob, makeRequire, name, ns, toAbsPath, _i, _j, _len, _len2, _ref;
var __indexOf = Array.prototype.indexOf || function(item) {
  for (var i = 0, l = this.length; i < l; i++) {
    if (this[i] === item) return i;
  }
  return -1;
};
base = _modul8RequireConfig;
ns = window[base.namespace];
domains = base.domains;
exports = {};
for (_i = 0, _len = domains.length; _i < _len; _i++) {
  name = domains[_i];
  exports[name] = {};
}
exports.data = ns.data;
delete ns.data;
exports.M8 = {};
exports.external = {};
arbiters = [];
_ref = base.arbiters;
for (name in _ref) {
  ary = _ref[name];
  arbiters.push(name);
  a = window[name];
  for (_j = 0, _len2 = ary.length; _j < _len2; _j++) {
    glob = ary[_j];
    delete window[glob];
  }
  exports.M8[name] = a;
}
DomReg = /^(.*)::/;
makeRequire = function(dom, pathName) {
  return function(reqStr) {
    var o, scannable, skipFolder, _k, _len3;
    if (base.logging) {
      console.log("" + dom + ":" + pathName + " <- " + reqStr);
    }
    if (reqStr.slice(0, 2) === './') {
      scannable = [dom];
      reqStr = toAbsPath(dom, pathName, reqStr.slice(2));
    } else if (DomReg.test(reqStr)) {
      scannable = [reqStr.match(DomReg)[1]];
      reqStr = reqStr.split('::')[1];
    } else if (__indexOf.call(arbiters, reqStr) >= 0) {
      scannable = ['M8'];
    } else {
      scannable = [dom].concat(domains.filter(function(e) {
        return e !== dom;
      }));
    }
    reqStr = reqStr.split('.')[0];
    if (reqStr.slice(-1) === '/') {
      reqStr += 'index';
      skipFolder = true;
    }
    for (_k = 0, _len3 = scannable.length; _k < _len3; _k++) {
      o = scannable[_k];
      if (exports[o][reqStr]) {
        return exports[o][reqStr];
      }
      if (!skipFolder && exports[o][reqStr + '/index']) {
        return exports[o][reqStr + '/index'];
      }
    }
    if (base.logging) {
      console.error("Unable to resolve require for: " + reqStr);
    }
    return null;
  };
};
toAbsPath = function(domain, pathName, relReqStr) {
  var folders;
  folders = pathName.split('/').slice(0, -1);
  while (relReqStr.slice(0, 3) === '../') {
    folders = folders.slice(0, -1);
    relReqStr = relReqStr.slice(3);
  }
  return folders.concat(relReqStr.split('/')).join('/');
};
ns.define = function(name, domain, fn) {
  var module;
  fn(makeRequire(domain, name), module = {}, exports[domain][name] = {});
  if (module.exports) {
    delete exports[domain][name];
    exports[domain][name] = module.exports;
  }
};
ns.inspect = function(domain) {
  console.log(exports[domain]);
};
ns.domains = function() {
  return domains.concat(['external']);
};
ns.require = makeRequire(base.main, 'CONSOLE');
exports.M8.data = ns.data = function(name, exported) {
  if (exports.data[name]) {
    delete exports.data[name];
  }
  if (exported) {
    exports.data[name] = exported;
  }
};
exports.M8.external = ns.external = function(name, exported) {
  if (exports.external[name]) {
    delete exports.exernal[name];
  }
  if (exported) {
    exports.extenal[name] = exported;
  }
};})();
M8.define('5','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/5','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('control/5','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('5','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('4','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/4','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('5','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('waa/5','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('waa/4','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('4','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('4','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/3','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('3','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('control/4','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('3','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
b = require('./branch1/3.js');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('3','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('control/3','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
b = require('./../3.js');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('2','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('waa/3','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
d = require('shared::branch1/3');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/2','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('2','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('waa/2','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
e = require('internal::2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('2','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('control/2','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('control/1','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('1','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('waa/1','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/1','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('1','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('1','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('control/0','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('0','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('0','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('waa/0','crazy',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/0','shared',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('0','internal',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/5','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/4','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch2/5','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch2/4','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./5');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/3','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch2/3','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./4');
b = require('./../branch1/3.js');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/2','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch2/2','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./3');
c = require('./../branch1/2.js');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch2/1','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/1','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./2');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch1/0','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('branch2/0','app',function(require, module, exports){var a = b = c = d = e = {chain:true};
a = require('./1');
exports.chain = a.chain && b.chain && c.chain && d.chain && e.chain;});
M8.define('entry','app',function(require, module, exports){exports.app_branch1 = require('branch1/0');
exports.app_branch2 = require('branch2/0');
exports.shared_ = require('shared::0');
exports.shared_branch1 = require('shared::branch1/0');
exports.internal_ = require('internal::0');
exports.internal_control = require('internal::control/0');
exports.crazy_waa = require('crazy::waa/0');
exports.crazy_ = require('crazy::0');});
})();
